package de.tu_darmstadt.tk.SmartHomeNetworkSim.core;

import java.util.Collection;

/**
 * Physical Link medium for SmartDevices, which connects two or more devices and allows communication between them
 *
 * @author Andreas T. Meyer-Berg
 */
public interface Link {
	/**
	 * @return the name
	 */
	public String getName();

	/**
	 * @param name the name to set
	 */
	public void setName(String name);

	/**
	 * @return the devices
	 */
	public Collection<SmartDevice> getDevices();

	/**
	 * @param device the devices to add
	 */
	public void addDevice(SmartDevice device);
	
	/**
	 * @param device the devices to remove
	 */
	public void removeDevice(SmartDevice device);
	
	/**
	 * Simulates an intervall starting at startTime for a given duration
	 * @param startTime 
	 * @param duration
	 */
	public void simulateTimeIntervall(long startTime, long duration);
	
	/**
	 * Returns all packets which where sent during the last Simulation time step
	 * @return packets, which were sent during the last time step
	 */
	public Collection<Packet> getPackets();
}
