package de.tu_darmstadt.tk.SmartHomeNetworkSim.core;

import java.util.Collection;
import java.util.LinkedList;
import java.util.ArrayList;

/**
 * Simple Implementation of {@link Link}, which allows connection of multiple devices
 *
 * @author Andreas T. Meyer-Berg
 */
public class SimpleLink implements Link {

	/**
	 * name of the connection
	 */
	private String name;
	
	/**
	 * Devices connected by this Link
	 */
	private ArrayList<SmartDevice> devices;

	private LinkedList<Packet> packets;
	/**
	 * Initializes a simple Link with name and an empty devices list.
	 * @param name
	 */
	public SimpleLink(String name){
		this.name = name;
		this.devices = new ArrayList<SmartDevice>();
		this.packets = new LinkedList<Packet>();
	}
	
	
	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the devices
	 */
	public Collection<SmartDevice> getDevices() {
		return devices;
	}

	/**
	 * @param device the devices to add
	 */
	public void addDevice(SmartDevice device) {
		this.devices.add(device);
	}
	
	/**
	 * @param device the devices to remove
	 */
	public void removeDevice(SmartDevice device) {
		this.devices.remove(device);
	}


	@Override
	public void simulateTimeIntervall(long startTime, long duration) {
		packets.clear();
		for(SmartDevice sd: devices)
			for(Connection c:sd.getConnections()){
				//Simulate just if source and link match
				if(c.getLink()==this && c.getSource() == sd)
					packets.addAll(c.simulateTimeIntervall(startTime, duration));
			}
	}


	@Override
	public Collection<Packet> getPackets() {
		return packets;
	}
}
