package de.tu_darmstadt.tk.SmartHomeNetworkSim.core;

import java.util.ArrayList;
import java.util.List;

/**
 * Model of an SmartDevice, which keeps track of its main attributes, like name
 * and links
 * 
 * @author Andreas T. Meyer-Berg
 */
public class SmartDevice {

	/**
	 * Name of the Device
	 */
	private String name;

	/**
	 * Physical connections to other SmartDevices
	 */
	private List<Link> links;
	
	/**
	 * Virtual Connections to other SmartDevices
	 */
	private List<Connection> connections;

	/**
	 * Creates a new SmartDevice without links
	 * 
	 * @param name
	 *            name of the device
	 */
	public SmartDevice(String name) {
		this.name = name;
		links = new ArrayList<Link>();
		connections = new ArrayList<Connection>();
	}

	/**
	 * Position on the x-Axis
	 */
	private int x;
	
	/**
	 * Positon on the y-Axis
	 */
	private int y;
	
	/**
	 * Position on the z-Axis
	 */
	private int z;
	
	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name
	 *            the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the links of this device
	 */
	public List<Link> getLinks() {
		return links;
	}

	/**
	 * @param link
	 *            the connection to add
	 */
	public void addLink(Link link) {
		this.links.add(link);
	}

	/**
	 * @return the x
	 */
	public int getX() {
		return x;
	}

	/**
	 * @param x the x to set
	 */
	public void setX(int x) {
		this.x = x;	
	}

	/**
	 * @return the y
	 */
	public int getY() {
		return y;
	}

	/**
	 * @param y the y to set
	 */
	public void setY(int y) {
		this.y = y;
	}

	/**
	 * @return the z
	 */
	public int getZ() {
		return z;
	}

	/**
	 * @param z the z to set
	 */
	public void setZ(int z) {
		this.z = z;
	}

	/**
	 * @return the connections
	 */
	public List<Connection> getConnections() {
		return connections;
	}

	/**
	 * @param connections the connections to set
	 */
	public void addConnection(Connection connections) {
		this.connections.add(connections);
	}

	/**
	 * Simulates the next Timestep
	 * @param startTime
	 * @param duration
	 */
	public void simulateTimeStep(long startTime, long duration) {
	}

}
